middleware

package
v0.0.0-...-171d8e8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2023 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FiberMiddleware

func FiberMiddleware(a *fiber.App)

Attaches the built-in Fiber middlewares to the given Fiber app

func KeycloakMiddlware

func KeycloakMiddlware(c *fiber.Ctx) error

Extracts the JWT from the Authorization header and validates it over Keycloak. The claims are then saved in the contexts Locals

Types

This section is empty.

Jump to