Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FiberMiddleware ¶
Attaches the built-in Fiber middlewares to the given Fiber app
func KeycloakMiddlware ¶
Extracts the JWT from the Authorization header and validates it over Keycloak. The claims are then saved in the contexts Locals
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.